@@ -6,8 +6,9 @@ from ..client.client import Session
 
 
 class CyberdropCrawler:
-    def __init__(self, *, include_id=False):
+    def __init__(self, *, include_id=False, quiet: bool):
         self.include_id = include_id
+        self.quiet = quiet
 
     async def fetch(self, session: Session, url: URL):
         domain_obj = DomainItem(url.host, {})
@@ -17,7 +18,7 @@ class CyberdropCrawler:
             await domain_obj.add_to_album(link=link, referral=url, title="Cyberdrop Loose Files")
             return domain_obj
 
-        await log("Starting scrape of " + str(url))
+        await log("Starting scrape of " + str(url), quiet=self.quiet)
 
         try:
             soup = await session.get_BS4(url)
@@ -40,9 +41,9 @@ class CyberdropCrawler:
 
         except Exception as e:
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log("Error scraping " + str(url))
+            await log("Error scraping " + str(url), quiet=self.quiet)
             logger.debug(e)
 
-        await log("Finished scrape of " + str(url))
+        await log("Finished scrape of " + str(url), quiet=self.quiet)
 
         return domain_obj
